@@ -11,5 +11,7 @@ enum keyword {
 	K_RLIMITDATA,
 	K_RLIMITSTACK,
 	K_RLIMITCORE,
-	K_RLIMITRSS
+	K_RLIMITRSS,
+	K_RLIMITNOFILE,
+	K_RLIMITVMEM
 };
